summaryrefslogtreecommitdiffstats
path: root/kpf/src/ServerSocket.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpf/src/ServerSocket.h')
-rw-r--r--kpf/src/ServerSocket.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpf/src/ServerSocket.h b/kpf/src/ServerSocket.h
index 76618c9b..13016672 100644
--- a/kpf/src/ServerSocket.h
+++ b/kpf/src/ServerSocket.h
@@ -29,14 +29,14 @@
namespace KPF
{
/**
* Used to help calculate how much of a QSocket's output buffer we can
* use before data will be sent out.
*/
- class ServerSocket : public QSocket
+ class ServerSocket : public TQSocket
{
public:
- ServerSocket(TQObject * parent, const char * name = 0);
+ ServerSocket(TQObject * tqparent, const char * name = 0);
uint outputBufferLeft();
};
@@ -29,14 +29,14 @@
{
/**
- * Used to help calculate how much of a QSocket's output buffer we can
+ * Used to help calculate how much of a TQSocket's output buffer we can
* use before data will be sent out.
*/